Who are you?

Author: zhongyujian, xwtester

https://github.com/sweeterio/who


## start

```python
from who import get_region
from who import validity_check


result = get_region(320)
print(result)


id="440304199010104562"
result = validity_check(id)
print(result)
```